@@ -9,7 +9,7 @@ Use print3() instead of print().
 """
 
 def print3(*args, **kwargs) :
-    """print3(value, ..., sep=' ', end='\n', file=sys.stdout, flush=False)
+    """print3(value, ..., sep=' ', end='\\n', file=sys.stdout, flush=False)
 
 Prints the values to a stream, or to sys.stdout by default.
 Optional keyword arguments:
@@ -21,11 +21,19 @@ flush: whether to forcibly flush the stream."""
     try :
         sep = kwargs["sep"]
         del kwargs["sep"]
+        if sep == None :
+            sep = " "
+        elif type(sep) != type("") :
+            raise TypeError("sep must be None or a string, not "+str(type(sep)))
     except KeyError :
         sep = " "
     try :
         end = kwargs["end"]
         del kwargs["end"]
+        if end == None :
+            end = "\n"
+        elif type(end) != type("") :
+            raise TypeError("end must be None or a string, not "+str(type(end)))
     except KeyError :
         end = "\n"
     try :
@@ -45,6 +53,11 @@ flush: whether to forcibly flush the stream."""
     for i in range(len(args)) :
         args[i] = str(args[i])
     args = tuple(args)
-    file.write(sep.join(args)+end)
+    message = ""
+    for i in args :
+        if message != "" :
+            message = message + sep
+        message = message + str(i)
+    file.write(message+end)
     if flush :
         file.flush()
